package com.jiuqi.util;

import java.util.Calendar;
import java.util.Date;
import java.sql.Time;
import java.text.ParseException;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;

public class DataConvert
{
    public static final int ftString = 12;
    public static final int ftInteger = 4;
    public static final int ftBoolean = -7;
    public static final int ftFloat = 2;
    public static final int ftDate = 91;
    public static final int ftDateTime = 93;
    public static final String[] BoolTrueCaptions;
    public static final String[] BoolFalseCaptions;
    public static final SimpleDateFormat default_date_format;
    public static final SimpleDateFormat default_time_format;
    
    static {
        BoolTrueCaptions = new String[] { "是", "真", "True", "T", "1" };
        BoolFalseCaptions = new String[] { "否", "假", "False", "F", "0" };
        default_date_format = new SimpleDateFormat("yyyy-MM-dd");
        default_time_format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    }
    
    public static int stringToInt(final String data) {
        try {
            return (data == null || data.equals("")) ? 0 : Integer.parseInt(data);
        }
        catch (final NumberFormatException ex) {
            return 0;
        }
    }
    
    public static boolean stringToBool(final String str) {
        if (str == null) {
            return false;
        }
        for (int i = 0; i < DataConvert.BoolTrueCaptions.length; ++i) {
            if (str.equalsIgnoreCase(DataConvert.BoolTrueCaptions[i])) {
                return true;
            }
        }
        return false;
    }
    
    public static Object stringToValue(final String data, final int zbtype) {
        if (data == null) {
            return null;
        }
        try {
            switch (zbtype) {
                case 12: {
                    return data;
                }
                case -7: {
                    return stringToBool(data) ? Boolean.TRUE : Boolean.FALSE;
                }
                case 4: {
                    try {
                        return data.equals("") ? null : Integer.valueOf(data);
                    }
                    catch (final NumberFormatException ex) {
                        return new Integer(Double.valueOf(data).intValue());
                    }
                }
                case 2: {
                    return data.equals("") ? null : Double.valueOf(data);
                }
                case 91: {
                    return DataConvert.default_date_format.parse(data);
                }
                case 93: {
                    return new Timestamp(DataConvert.default_time_format.parse(data).getTime());
                }
            }
        }
        catch (final NumberFormatException ex2) {}
        catch (final ParseException ex3) {}
        return null;
    }
    
    public static String valueToString(final int value) {
        return String.valueOf(value);
    }
    
    public static String valueToString(final Object value) {
        return valueToString(value, false);
    }
    
    public static String valueToString(final Object value, final boolean quoteString) {
        if (value == null) {
            return null;
        }
        if (value instanceof Double) {
            return value.toString();
        }
        if (value instanceof Integer) {
            return value.toString();
        }
        if (value instanceof Boolean) {
            return value ? "1" : "0";
        }
        if (value instanceof String) {
            if (!quoteString) {
                return (String)value;
            }
            return JqLib.quoteString((String)value);
        }
        else {
            if (value instanceof Time) {
                return DataConvert.default_time_format.format((Date)value);
            }
            if (value instanceof Timestamp) {
                return DataConvert.default_time_format.format((Date)value);
            }
            if (value instanceof Date) {
                return DataConvert.default_date_format.format((Date)value);
            }
            if (value instanceof Calendar) {
                return DataConvert.default_date_format.format(((Calendar)value).getTime());
            }
            return value.toString();
        }
    }
    
    public static String valuesToString(final Object value, final boolean quoteString) {
        if (value == null) {
            return null;
        }
        if (value instanceof Object[]) {
            final Object[] values = (Object[])value;
            String result = "";
            for (int i = 0; i < values.length; ++i) {
                result = String.valueOf(result) + valueToString(values[i], quoteString) + ';';
            }
            return result;
        }
        return valueToString(value, quoteString);
    }
}
